@@ -65,10 +65,15 @@ def activate_line(x, y, z, command, tile_type=""):
 		try:
 			g.maps[z].field[y + g.ygrid][x + g.xgrid].del_pix(
 				g.tiles[command.split(None, 2)[1]])
+			main.refreshmap()
 			return_num = 1
 		except ValueError:
 			return_num = 0
 
+	elif switch == "dialog":  #show a message in a dialog box.
+		main.show_dialog(command.split(None, 1)[1])
+		return_num = 1
+
 	elif switch == "die":  #process endgame.txt script
 		g.hp = -1
 		for line in g.endgame_act:
