@@ -11,10 +11,16 @@ import Image
 import tkMessageBox
 import g
 import main
+import action
 
 global listbox_array
 listbox_array = []
 
+global active_button
+active_button = 0
+
+return_from_yesno = StringVar()
+
 #these variables hold the name of the wielded equipment
 weapon_name = StringVar()
 armor_name = StringVar()
@@ -39,12 +45,14 @@ leave_height = 0
 
 #called when "Save" is pressed
 def inv_savegame():
+	if action.has_dialog == 1: return 0
 	g.savegame(g.name)
 	main.print_message("** Game Saved **")
 	help_text.set("Game Saved")
 
 #called when "Leave" is pressed
 def leave_inv():
+	if action.has_dialog == 1: return 0
 	try:
 		window_inv.destroy()
 	except TclError:
@@ -52,6 +60,7 @@ def leave_inv():
 
 #puts a worn item into the inventory. Called from the remove button.
 def rm_equip():
+	if action.has_dialog == 1: return 0
 	if (len(listbox_equip.curselection()) > 0):
 		try: item_num = map(int, listbox_equip.curselection())
 		except ValueError: pass
@@ -64,6 +73,7 @@ def rm_equip():
 
 #takes an item from the inventory, and wears it.
 def wear_item():
+	if action.has_dialog == 1: return 0
 	#put the item[] index of the item into item_value
 	try:
 		item_num = map(int, listbox_inv.curselection())
@@ -84,28 +94,114 @@ def wear_item():
 		g.equip[item_loc] = item_value
 		g.drop_inv_item(item_num[0])
 		g.take_inv_item(temp)
-		main.print_message("You equip yourself with your " + 
+		main.print_message("You equip yourself with your " +
 			g.item[g.equip[item_loc]][0] + ".")
 		refresh_inv()
 
 #drops an item from the inventory. Uses the
 #position of the listbox_inv listbox
 def drop_item():
+	if action.has_dialog == 1: return 0
 	try: item_num = map(int, listbox_inv.curselection())
 	except ValueError: pass
 	try:
 		item_to_delete = g.find_inv_item(listbox_array[item_num[0]])
 	except IndexError: return 0
 
-	if tkMessageBox.askyesno("Drop?", "Drop your " +
-			g.item[g.inv[item_to_delete]][0] + "?", parent=window_inv):
+	#the inv[] location of the item is now in item_to_delete.
+	#Ask if the player really wants to drop it.
+
+	if inv_show_yesno("Drop your " + g.item[g.inv[item_to_delete]][0] + "?"):
 		main.print_message("You drop your " + g.item[g.inv[item_num[0]]][0])
 		g.drop_inv_item(item_num[0])
 
 	refresh_inv()
 
+#Like show_yesno in main, but only expects one or two lines,
+#and creates the canvas used.
+def inv_show_yesno(line=""):
+	action.has_dialog = 1
+	global active_button
+	active_button = 0
+	global return_from_yesno
+	return_from_yesno.set("0")
+
+	canvas_width = no_button.width()*4/3+yes_button.width()*4/3
+	canvas_height = yes_button.height()+50
+	global canvas_inv
+	canvas_inv = Canvas(window_inv, width=canvas_width,
+		height=canvas_height, highlightthickness=0)
+	canvas_inv.grid(column=1, row=2, columnspan=2, rowspan=7, sticky="S")
+
+	#background
+	canvas_inv.create_rectangle(0, 0, canvas_width, canvas_height,
+		fill="#5050ff", outline="Black", tags="background_box")
+	#text
+	canvas_inv.create_text(3, 3, text=line, anchor="nw",
+		width=canvas_width-6, tags="dialogtxt")
+	#buttons
+	canvas_inv.create_image(canvas_width/2,
+		canvas_height, image=no_button_sel, anchor="se", tags="no")
+	canvas_inv.create_image(canvas_width/2,
+		canvas_height, image=yes_button, anchor="sw", tags="yes")
+	#bindings
+	main.window_main.bind("<Up>", change_yesno_sel)
+	main.window_main.bind("<Right>", change_yesno_sel)
+	main.window_main.bind("<Left>", change_yesno_sel)
+	main.window_main.bind("<Down>", change_yesno_sel)
+	main.window_main.bind("<Return>", activate_yesno)
+	canvas_inv.tag_bind("no", "<Enter>", change_yesno_to_no)
+	canvas_inv.tag_bind("yes", "<Enter>", change_yesno_to_yes)
+	canvas_inv.tag_bind("no", "<Button-1>", activate_yesno)
+	canvas_inv.tag_bind("yes", "<Button-1>", activate_yesno)
+
+	#wait. Continue after activate_yesno() is run.
+	window_inv.wait_variable(return_from_yesno)
+	#cleanup
+	try: canvas_inv.destroy()
+	except TclError: return 1
+
+	main.window_main.bind("<Escape>", key_handler_esc)
+	main.window_main.bind("<Return>", key_handler_return)
+	main.window_main.bind("<Up>", key_handler_up)
+	main.window_main.bind("<Down>", key_handler_down)
+	main.window_main.bind("<Left>", key_handler_left)
+	main.window_main.bind("<Right>", key_handler_right)
+	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
+	canvas_buttons.bind("<Motion>", mouse_handler_move)
+	listbox_inv.bind("<ButtonRelease-1>", refresh_buttons)
+
+	action.has_dialog = 0
+	return active_button
+
+#when a yesno dialog box is active, switch to yes.
+def change_yesno_to_yes(event=None):
+	global active_button
+	active_button = 1
+	canvas_inv.itemconfigure("no", image=no_button)
+	canvas_inv.itemconfigure("yes", image=yes_button_sel)
+
+#when a yesno dialog box is active, switch to no.
+def change_yesno_to_no(event=None):
+	global active_button
+	active_button = 0
+	canvas_inv.itemconfigure("no", image=no_button_sel)
+	canvas_inv.itemconfigure("yes", image=yes_button)
+
+#when a yesno dialog box is active, switch the yes and no buttons.
+def change_yesno_sel(event=None):
+	if active_button == 0: change_yesno_to_yes()
+	else: change_yesno_to_no()
+
+#called on Return when the yesno dialog box is active.
+def activate_yesno(event=None):
+	global return_from_yesno
+	return_from_yesno.set("1")
+
+
 #called when "Use" is pressed
 def use_item():
+	if action.has_dialog == 1: return 0
 	#put the item[] index of the item into item_value
 	try: item_num = map(int, listbox_inv.curselection())
 	except ValueError: pass
@@ -129,6 +225,7 @@ def use_item():
 
 #refresh buttons.
 def refresh_buttons(event=0):
+	if action.has_dialog == 1: return 0
 	canvas_buttons.delete(ALL)
 	if (cur_button == 0):
 		canvas_buttons.create_image(0, 0, anchor=NW, image=drop_button_sel)
@@ -184,6 +281,7 @@ def refresh_buttons(event=0):
 
 #refresh this screen. Call after moving around items.
 def refresh_inv():
+	if action.has_dialog == 1: return 0
 	#place current position into item_num[0], for restoring position.
 	try: item_num = map(int, listbox_inv.curselection())
 	except ValueError: pass
@@ -248,6 +346,7 @@ def refresh_inv():
 #All keypresses in window_inv pass through here. Based on the key name,
 #give the right action. ("etc", "left", "right", "up", "down", "return")
 def key_handler(key_name):
+	if action.has_dialog == 1: return 0
 	global cur_button
 	if (key_name == "esc"):
 		leave_inv()
@@ -338,9 +437,11 @@ def key_handler_up(event=0): key_handler("up")
 def key_handler_return(event=0): key_handler("return")
 
 def mouse_handler_click(event=0):
+	if action.has_dialog == 1: return 0
 	key_handler("return")
 
 def mouse_handler_move(event=0):
+	if action.has_dialog == 1: return 0
 	global cur_button
 	if (event.x < use_height):
 		cur_button = 0
@@ -387,6 +488,8 @@ def init_window_inv():
 	global save_button; global save_button_sel
 	global remove_button; global remove_button_sel
 	global leave_button; global leave_button_sel
+	global yes_button; global yes_button_sel
+	global no_button; global no_button_sel
 
 	drop_button = ImageTk.PhotoImage(file=g.mod_directory + \
 		"/images/buttons/drop.png")
@@ -402,6 +505,10 @@ def init_window_inv():
 		"/images/buttons/remove.png")
 	leave_button = ImageTk.PhotoImage(file=g.mod_directory + \
 		"/images/buttons/leave.png")
+	yes_button = ImageTk.PhotoImage(file=g.mod_directory + \
+		"/images/buttons/yes.png")
+	no_button = ImageTk.PhotoImage(file=g.mod_directory + \
+		"/images/buttons/no.png")
 
 	drop_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
 		"/images/buttons/drop_sel.png")
@@ -417,6 +524,10 @@ def init_window_inv():
 		"/images/buttons/remove_sel.png")
 	leave_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
 		"/images/buttons/leave_sel.png")
+	yes_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
+		"/images/buttons/yes_sel.png")
+	no_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
+		"/images/buttons/no_sel.png")
 
 	#location of the various buttons.
 	global use_height; use_height = drop_button.width()
