@@ -22,7 +22,8 @@ import action
 
 #size, in tiles, of the main screen. While this is adjustable,
 #an odd number would work much better. (To keep the player centered.)
-mapsize = 13
+mapsizex = 19
+mapsizey = 13
 
 sidebarsize = 5
 status_box_width = 19
@@ -127,14 +128,15 @@ def activate_scripting(x, y, z):
 #redraws the main map. Call after moving.
 def refreshmap():
 	#redraw the tiles
-	half_map = mapsize/2 #division is nasty. Only do it once.
+	half_mapx = mapsizex/2 #division is nasty. Only do it once.
+	half_mapy = mapsizey/2
 	canvas_map.delete(ALL)
-	for x in range(mapsize):
-		for y in range(mapsize):
-			for picture in findtile(x-half_map, y-half_map):
+	for x in range(mapsizex):
+		for y in range(mapsizey):
+			for picture in findtile(x-half_mapx, y-half_mapy):
 				canvas_map.create_image(x*g.tilesize, y*g.tilesize,
 					anchor=NW, image=picture,
-					tags=str(g.xgrid+x-half_map)+"."+str(g.ygrid+y-half_map))
+					tags=str(g.xgrid+x-half_mapx)+"."+str(g.ygrid+y-half_mapy))
 
 	refreshhero()
 	recalc_stats()
@@ -142,7 +144,7 @@ def refreshmap():
 #refreshs the hero; faster than refreshing the whole map.
 def refreshhero():
 	canvas_map.delete("hero")
-	canvas_map.create_image(mapsize*g.tilesize/2, mapsize*g.tilesize/2,
+	canvas_map.create_image(mapsizex*g.tilesize/2, mapsizey*g.tilesize/2,
 		image=g.tiles[g.cur_hero], tags="hero")
 
 
@@ -194,6 +196,8 @@ def recalc_stats():
 	level.set(g.level)
 
 
+#Return an array of pictures that the given tile should display.
+#x and y are relative to the player.
 def findtile(x, y):
 	#g.maps[g.zgrid].field[][].pix)
 	#transform from relative to absolute coordinates
@@ -257,56 +261,49 @@ def move_hero(x, y):
 				canvas_map.move(ALL, -x*tilesize, -y*tilesize)
 
 				#Refreshes the new part.
-				half_map = mapsize/2
+				half_mapx = mapsizex/2
+				half_mapy = mapsizey/2
 				refreshhero()
 				recalc_stats()
 				g.allow_move = 1
 				if y == -1:
-					for tilenum in range(mapsize):
-						if len(canvas_map.gettags(str(g.xgrid+
-							tilenum-half_map)+"."+str(g.ygrid-half_map))) == 1:
-							continue
-						canvas_map.delete(str(g.xgrid+
-							tilenum-half_map)+"."+str(g.ygrid-half_map))
-						for picture in findtile(tilenum-half_map, -half_map):
+					for tilenum in range(mapsizex):
+						search_for = str(g.xgrid+tilenum-half_mapx)+"."+ \
+							str(g.ygrid-half_mapy)
+						if len(canvas_map.gettags(search_for)) == 1: continue
+						canvas_map.delete(search_for)
+						for picture in findtile(tilenum-half_mapx, -half_mapy):
 							canvas_map.create_image(tilenum*g.tilesize, 0,
-							anchor=NW, image=picture, tags=str(g.xgrid+
-							tilenum-half_map)+"."+str(g.ygrid-half_map))
+							anchor=NW, image=picture, tags=search_for)
 				if y ==  1:
-					for tilenum in range(mapsize):
-						if len(str(g.xgrid+ tilenum-half_map)+"."+
-							str(g.ygrid+half_map)) == 1:
-							continue
-						canvas_map.delete(str(g.xgrid+ tilenum-half_map)+"."+
-							str(g.ygrid+half_map))
-						for picture in findtile(tilenum-half_map, half_map):
+					for tilenum in range(mapsizex):
+						search_for = str(g.xgrid+ tilenum-half_mapx)+"."+ \
+							str(g.ygrid+half_mapy)
+						if len(canvas_map.gettags(search_for)) == 1: continue
+						canvas_map.delete(search_for)
+						for picture in findtile(tilenum-half_mapx, half_mapy):
 							canvas_map.create_image(tilenum*g.tilesize,
-							g.tilesize*(mapsize-1), anchor=NW, image=picture,
-							tags=str(g.xgrid+ tilenum-half_map)+"."+
-							str(g.ygrid+half_map))
+							g.tilesize*(mapsizey-1), anchor=NW, image=picture,
+							tags=search_for)
 				if x == -1:
-					for tilenum in range(mapsize):
-						if len(canvas_map.gettags(str(g.xgrid-half_map)
-							+"."+ str(g.ygrid+tilenum-half_map))) == 1:
-							continue
-						canvas_map.delete(str(g.xgrid
-							-half_map) +"."+ str(g.ygrid+tilenum-half_map))
-						for picture in findtile(-half_map, tilenum-half_map):
+					for tilenum in range(mapsizey):
+						search_for = str(g.xgrid-half_mapx)+"."+ \
+							str(g.ygrid+tilenum-half_mapy)
+						if len(canvas_map.gettags(search_for)) == 1: continue
+						canvas_map.delete(search_for)
+						for picture in findtile(-half_mapx, tilenum-half_mapy):
 							canvas_map.create_image(0, tilenum*g.tilesize,
-							anchor=NW, image=picture, tags=str(g.xgrid
-							-half_map) +"."+ str(g.ygrid+tilenum-half_map))
+							anchor=NW, image=picture, tags=search_for)
 				if x ==  1:
-					for tilenum in range(mapsize):
-						if len(str(g.xgrid+half_map) +"."+
-							str(g.ygrid+tilenum-half_map)) == 1:
-							continue
-						canvas_map.delete(str(g.xgrid+half_map) +"."+
-							str(g.ygrid+tilenum-half_map))
-						for picture in findtile(half_map, tilenum-half_map):
-							canvas_map.create_image(g.tilesize*(mapsize-1),
+					for tilenum in range(mapsizey):
+						search_for = str(g.xgrid+half_mapx) +"."+ \
+							str(g.ygrid+tilenum-half_mapy)
+						if len(canvas_map.gettags(search_for)) == 1: continue
+						canvas_map.delete(search_for)
+						for picture in findtile(half_mapx, tilenum-half_mapy):
+							canvas_map.create_image(g.tilesize*(mapsizex-1),
 							tilenum*g.tilesize, anchor=NW, image=picture,
-							tags=str(g.xgrid+half_map) +"."+
-							str(g.ygrid+tilenum-half_map))
+							tags=search_for)
 
 		else:
 			if y == -1: g.cur_hero = "people/hero_n.png"
@@ -387,7 +384,40 @@ def start_battle(mon_index):
 def show_dialog(line=None):
 	if window_main.state() != "normal":
 		return 0
-	tkMessageBox.showinfo(g.game_name, line, parent=window_main)
+
+	action.has_dialog = 1
+	global return_from_yesno
+	return_from_yesno.set("0")
+	#text
+	canvas_map.create_text((mapsizex*tilesize/2),
+		(6*mapsizey*tilesize/7), text=line, anchor="s",
+		width=no_button.width()*4/3+yes_button.width()*4/3-6, tags="dialogtxt")
+	#generate the background size.
+	x1, y1, x2, y2 = canvas_map.bbox("dialogtxt")
+	if x1 > (mapsizex*tilesize/2) - no_button.width():
+		x1 = (mapsizex*tilesize/2) - no_button.width()
+	if x2 < (mapsizex*tilesize/2) + yes_button.width():
+		x2 = (mapsizex*tilesize/2) + yes_button.width()
+	#background
+	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
+		fill="#5050ff", outline="Black", tags="background_box")
+	canvas_map.lift("dialogtxt")
+	#button
+	canvas_map.create_image((mapsizex*tilesize/2),
+		(6*mapsizey*tilesize/7), image=begin_button_sel, anchor="n", tags="ok")
+	#bindings
+	window_main.bind("<Return>", activate_yesno)
+	canvas_map.tag_bind("ok", "<Button-1>", activate_yesno)
+	#wait. Continue after activate_yesno() is run.
+	window_main.wait_variable(return_from_yesno)
+	#cleanup
+	try:
+		if window_main.state() != "normal": return 1
+	except TclError: return 1
+	bind_keys()
+	canvas_map.bind("<Button-1>", mouse_handler)
+	action.has_dialog = 0
+	canvas_map.delete("dialogtxt", "ok", "background_box")
 	return 1
 
 #given a string, display that string, along with yes and no buttons.
@@ -400,24 +430,24 @@ def show_yesno(line=""):
 	global return_from_yesno
 	return_from_yesno.set("0")
 	#text
-	canvas_map.create_text((mapsize*tilesize/2),
-		(6*mapsize*tilesize/7), text=line, anchor="s",
+	canvas_map.create_text((mapsizex*tilesize/2),
+		(6*mapsizey*tilesize/7), text=line, anchor="s",
 		width=no_button.width()*4/3+yes_button.width()*4/3-6, tags="dialogtxt")
 	#generate the background size.
 	x1, y1, x2, y2 = canvas_map.bbox("dialogtxt")
-	if x1 > (mapsize*tilesize/2) - no_button.width():
-		x1 = (mapsize*tilesize/2) - no_button.width()
-	if x2 < (mapsize*tilesize/2) + yes_button.width():
-		x2 = (mapsize*tilesize/2) + yes_button.width()
+	if x1 > (mapsizex*tilesize/2) - no_button.width():
+		x1 = (mapsizex*tilesize/2) - no_button.width()
+	if x2 < (mapsizex*tilesize/2) + yes_button.width():
+		x2 = (mapsizex*tilesize/2) + yes_button.width()
 	#background
 	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
 		fill="#5050ff", outline="Black", tags="background_box")
 	canvas_map.lift("dialogtxt")
 	#buttons
-	canvas_map.create_image((mapsize*tilesize/2),
-		(6*mapsize*tilesize/7), image=no_button_sel, anchor="ne", tags="no")
-	canvas_map.create_image((mapsize*tilesize/2),
-		(6*mapsize*tilesize/7), image=yes_button, anchor="nw", tags="yes")
+	canvas_map.create_image((mapsizex*tilesize/2),
+		(6*mapsizey*tilesize/7), image=no_button_sel, anchor="ne", tags="no")
+	canvas_map.create_image((mapsizex*tilesize/2),
+		(6*mapsizey*tilesize/7), image=yes_button, anchor="nw", tags="yes")
 	#bindings
 	window_main.bind("<Up>", change_yesno_sel)
 	window_main.bind("<Right>", change_yesno_sel)
@@ -485,7 +515,7 @@ def init_window_main(new_game = 0):
 	main_frame.grid(row=0, column=0)
 
 	#top frame contains left and right
-	top = Frame(main_frame, bd=2, relief=SUNKEN, bg=bgcolour);
+	top = Frame(main_frame, bd=1, relief=SUNKEN, bg=bgcolour);
 	top.grid(row=0, column=0, columnspan=width, sticky=NW)
 
 	#status window, scrollbar
@@ -519,6 +549,9 @@ def init_window_main(new_game = 0):
 		"/images/buttons/no.png")
 	no_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
 		"/images/buttons/no_sel.png")
+	global begin_button_sel
+	begin_button_sel = ImageTk.PhotoImage(file=g.mod_directory + \
+		"/images/buttons/begin_sel.png")
 
 	#left (stats) side frame
 	global left
@@ -616,6 +649,7 @@ def init_window_main(new_game = 0):
 	#keep the new_game window asleep until this one is closed.
 	window_main.master.wait_window(window_main)
 
+#needed for some bindings.
 def do_nothing(event=0):
 	pass
 
@@ -635,22 +669,29 @@ def bind_keys():
 
 #handles mouse clicks on the main tile canvas.
 def mouse_handler(event=0):
-	if (event.x < event.y): #south or west
-		if (event.x + event.y > mapsize*g.tilesize): move_south()
+	if mapsizex > mapsizey:
+		mapsz = mapsizey*g.tilesize
+		mapstartx = (mapsizex*g.tilesize - mapsz)/2
+		mapstarty = 0
+	else:
+		mapsz = mapsizex*g.tilesize
+		mapstartx = 0
+		mapstarty = (mapsizey*g.tilesize - mapsz)/2
+	if (event.x - mapstartx < event.y - mapstarty): #south or west
+		if (event.x + event.y > mapstartx+mapstarty+mapsz): move_south()
 		else: move_west()
 	else: #north or east
-		if (event.x + event.y > mapsize*g.tilesize): move_east()
+		if (event.x + event.y > mapstartx+mapstarty+mapsz): move_east()
 		else: move_north()
 
-
 def create_map():
 	#right side frame contains map
 	global right
 	right = Frame(top,bd=2, relief=SUNKEN, bg=bgcolour);
-	right.grid(row=1, column=sidebarsize, columnspan=mapsize, sticky=E)
+	right.grid(row=1, column=sidebarsize, columnspan=mapsizex, sticky=E)
 	global canvas_map
-	canvas_map = Canvas(right, width=g.tilesize*mapsize,
-		height=g.tilesize*mapsize, highlightthickness=0)
+	canvas_map = Canvas(right, width=g.tilesize*mapsizex,
+		height=g.tilesize*mapsizey, highlightthickness=0)
 	canvas_map.grid(column=0, row=0)
 	canvas_map.bind("<Button-1>", mouse_handler)
 
